@@ -1,3 +1,4 @@
+from datetime import datetime, timedelta
 import re
 from pathlib import Path
 
@@ -12,7 +13,7 @@ class FramesDir:
 
     @property
     def movies(self):
-        return Path(self.directory).glob('*_fractions.mrc')
+        return Path(self.directory).glob('*_fractions.*')
 
     @property
     def mdoc_images(self):
@@ -126,6 +127,11 @@ class MdocImage:
     def basename(self):
         return self.regex.group(1)
 
+    @property
+    def time(self) -> str:
+        time = datetime.now() + timedelta(minutes=1*self.image_idx)
+        return time.strftime('%H:%M:%S')
+
     @property
     def body(self):
         body = [f"[ZValue = {self.image_idx}]",
@@ -151,7 +157,7 @@ class MdocImage:
                 fr"SubFramePath = X:\spoof\frames\{self.image_file}",
                 "NumSubFrames = 15",
                 "FrameDosesAndNumber = 0 15",
-                "DateTime = 24-Sep-18  16:47:20",
+                f"DateTime = 24-Sep-18  {self.time}",
                 "NavigatorLabel = 37",
                 "\n"
                 ]
